@@ -16,8 +16,11 @@ from unidecode import unidecode
 from ..data.categories import title_map, root_map, ing_keys, ing_map, exceptions
 # from data.categories import title_map, root_map, ing_keys, ing_map, exceptions
 import spacy
+import os
 
-nlp = spacy.load("en_core_web_sm")
+ROOT_DIR = os.path.realpath(os.path.join(os.path.dirname(__file__), '..'))
+en_core_web_sm = os.path.join(ROOT_DIR, 'models', 'en_core_web_sm')
+nlp = spacy.load(en_core_web_sm)
 
 
 class RecipeReader:
